/vpcs/{uuid}/start — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /vpcs/{uuid}/start

Contents

- /vpcs/{uuid}/start
  - POST /vpcs/{uuid}/start
    - Parameters
    - Response status codes

## POST /vpcs/{uuid}/start

Start a VPCS instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 400: Invalid VPCS instance UUID
- 404: Instance doesn’t exist
- 204: Instance started

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »